@@ -5,10 +5,12 @@ Appendix
 The @@appendix and @@about views.
 """
 
-import logging
-from zope.interface import Interface
-from five import grok
 from euphorie.client.interfaces import IClientSkinLayer
+from five import grok
+from zope.interface import Interface
+
+import logging
+
 
 log = logging.getLogger(__name__)
 
@@ -16,8 +18,8 @@ grok.templatedir("templates")
 
 
 class About(grok.View):
-    """View name: @@about
-    """
+    """View name: @@about"""
+
     grok.context(Interface)
     grok.layer(IClientSkinLayer)
     grok.name("about")
