@@ -24,6 +24,7 @@ from euphorie.client.survey import _StatusHelper
 from euphorie.client.update import treeChanges
 from euphorie.content.interfaces import ICustomRisksModule
 from euphorie.content.profilequestion import IProfileQuestion
+from euphorie.content.solution import ISolution
 from plone import api
 from plone.app.event.base import localized_now
 from plone.autoform.form import AutoExtensibleForm
@@ -49,7 +50,7 @@ import urllib
 
 
 def sql_clone(obj, skip={}, session=None):
-    """ Clone a sql object avoiding the properties in the skip parameter
+    """Clone a sql object avoiding the properties in the skip parameter
 
     The skip parameter is optional but you probably want to always pass the
     primary key
@@ -78,8 +79,7 @@ class IStartFormSchema(model.Schema):
 
 
 class SessionMixin(object):
-    """ Mostly properties we want to reuse for the views in the context of a session
-    """
+    """Mostly properties we want to reuse for the views in the context of a session"""
 
     def update(self):
         super(SessionMixin, self).update()
@@ -93,8 +93,7 @@ class SessionMixin(object):
     @property
     @memoize
     def survey(self):
-        """ This is the survey dexterity object
-        """
+        """This is the survey dexterity object"""
         return self.webhelpers._survey
 
     @property
@@ -125,7 +124,7 @@ class SessionMixin(object):
         scales = self.survey.restrictedTraverse("@@images")
         try:
             scale = scales.scale("external_site_logo", scale="large")
-        except:
+        except Exception:
             scale = None
         return scale.url if scale else ""
 
@@ -163,10 +162,13 @@ class Start(SessionMixin, AutoExtensibleForm, EditForm):
             target_language=lang,
         )
 
+    @property
+    def message_gt1(self):
+        return api.portal.translate(_(u"This value must be greater than or equal to 1"))
+
     @memoize
     def get_pat_messages_above_title(self):
-        """ List of messages we want to display above the risk assesment title
-        """
+        """List of messages we want to display above the risk assesment title"""
         if not self.webhelpers.can_edit_session:
             link_download_section = _(
                 "no_translate_link_download_section",
@@ -175,7 +177,8 @@ class Start(SessionMixin, AutoExtensibleForm, EditForm):
                 mapping={"text_download_section": _(u"download section")},
             )
             message = _(
-                u"You don't have edit rights for this risk assesment, but you can download "
+                u"You don't have edit rights for this risk assesment, "
+                u"but you can download "
                 u"this risk assessment in various forms in the ${download_section}.",
                 mapping={"download_section": link_download_section},
             )
@@ -184,7 +187,7 @@ class Start(SessionMixin, AutoExtensibleForm, EditForm):
 
     @memoize
     def get_pat_multiple_messages_below_article(self):
-        """ List of messages we want to display under the risk assesment article
+        """List of messages we want to display under the risk assesment article
 
         Those messages should be iterable.
         Example of a good returned value:
@@ -205,6 +208,7 @@ class Start(SessionMixin, AutoExtensibleForm, EditForm):
 
     def update(self):
         self.verify_view_permission()
+        utils.setLanguage(self.request, self.survey, self.survey.language)
         super(Start, self).update()
         if self.request.method != "POST":
             return
@@ -234,9 +238,12 @@ class Profile(SessionMixin, AutoExtensibleForm, EditForm):
     survey.
     """
 
-    id_patt = re.compile("pq([0-9]*)\.present")
+    id_patt = re.compile(r"pq([0-9]*)\.present")
     variation_class = "variation-risk-assessment"
-    next_view_name = "@@identification"
+
+    @property
+    def next_view_name(self):
+        return "@@involve" if self.webhelpers.use_involve_phase else "@@identification"
 
     @property
     def template(self):
@@ -309,7 +316,9 @@ class Profile(SessionMixin, AutoExtensibleForm, EditForm):
             # At this stage, we actually do not need to touch the session.
             # It is enough that it gets touched when a Risk is edited, or if the
             # tree gets rebuilt due to changes.
-            # survey_session.touch()
+            # Touch means: the modification timestamp is set.
+            # But we need to make sure the refreshed marker is up to date!
+            survey_session.refresh_survey(survey)
             return survey_session
 
         params = {}
@@ -397,6 +406,7 @@ class Profile(SessionMixin, AutoExtensibleForm, EditForm):
         )
 
     def update(self):
+        utils.setLanguage(self.request, self.survey, self.survey.language)
         if not self.profile_questions or self.request.method == "POST":
             new_session = self.setupSession()
             self.request.response.redirect(
@@ -418,14 +428,113 @@ class Update(Profile):
     detailed instructions for the user.
     """
 
+
+class Involve(SessionMixin, BrowserView):
+    """Inform the user about options for involving coworkers."""
+
+    variation_class = "variation-risk-assessment"
     next_view_name = "@@identification"
 
+    def next_url(self):
+        return "{context_url}/{target}".format(
+            context_url=self.context.absolute_url(), target=self.next_view_name
+        )
+
+    def __call__(self):
+        utils.setLanguage(self.request, self.survey, self.survey.language)
+        return super(Involve, self).__call__()
+
+
+class ContentsPreview(BrowserView):
+    """A View for displaying the full contents of a tool and printing them
+
+    View name: @@contents-preview
+    """
+
+    no_splash = True
+
+    @property
+    def extra_text(self):
+        appconfig = getUtility(IAppConfig)
+        settings = appconfig.get("euphorie")
+        have_extra = settings.get("extra_text_identification", False)
+        if not have_extra:
+            return None
+        return api.portal.translate(_(u"extra_text_identification", default=u""))
+
+    @property
+    @memoize
+    def webhelpers(self):
+        return api.content.get_view("webhelpers", self.context.aq_parent, self.request)
+
+    @property
+    def title_custom_risks(self):
+        return api.portal.translate(
+            _("title_other_risks", default=u"Added risks (by you)")
+        )
+
+    def get_session_nodes(self):
+        """Return an ordered list of all tree items for the current survey.
+        By OSHA's request, optional submodules are always included.
+        """
+        query = (
+            Session.query(SurveyTreeItem)
+            .filter(SurveyTreeItem.session == self.context.session)
+            .order_by(SurveyTreeItem.path)
+        )
+
+        return query.all()
+
+    @memoize
+    def zodb_node(self, node):
+        if node.zodb_path.find("custom-risks") > -1:
+            return
+        return self.context.aq_parent.restrictedTraverse(node.zodb_path.split("/"))
+
+    def get_title(self, node):
+        if node.zodb_path.find("custom-risks") > -1:
+            return self.title_custom_risks
+        else:
+            return node.title
+
+    def get_legal_references(self, node):
+        """We might add some logic to never show legal references depending
+        on a setting per country / survey.
+        """
+        zodb_node = self.zodb_node(node)
+        if not zodb_node:
+            return
+        return getattr(zodb_node, "legal_reference", None)
+
+    def get_solutions(self, node):
+        solutions = []
+        zodb_node = self.zodb_node(node)
+        if not zodb_node:
+            return solutions
+        mode = getattr(self.webhelpers._survey, "measures_text_handling", "full")
+        for solution in zodb_node.values():
+            if not ISolution.providedBy(solution):
+                continue
+            if mode == "full":
+                text = u"{title}<br/>{description}".format(
+                    title=solution.description, description=solution.action
+                )
+            else:
+                text = solution.action
+            solutions.append(text)
+        return solutions
+
 
 class Identification(SessionMixin, BrowserView):
     """Survey identification start page.
 
-    This view shows the introduction text for the identification phase. This
-    includes an option to print a report with all questions.
+    This view is legacy. We used to have an introduction page in the identification
+    phase before the first module was shown. That intro is not wanted any more,
+    so we just redirect to the first module.
+    Since not all installations of OiRA (TNO!) have made this switch, we temporarily
+    keep this view.
+
+    @Todo: Modify class Profile so that we immediately traverse to the first module.
 
     View name: @@identification
     """
@@ -498,12 +607,14 @@ class Identification(SessionMixin, BrowserView):
                 self.context.absolute_url() + "/@@start"
             )
         utils.setLanguage(self.request, self.survey, self.survey.language)
-        return super(Identification, self).__call__()
+        if self.webhelpers.use_involve_phase:
+            self.request.RESPONSE.redirect(self.next_url)
+        else:
+            return super(Identification, self).__call__()
 
 
 class DeleteSession(SessionMixin, BrowserView):
-    """View name: @@delete-session
-    """
+    """View name: @@delete-session"""
 
     def __call__(self):
         if not self.webhelpers.can_delete_session:
@@ -522,8 +633,7 @@ class DeleteSession(SessionMixin, BrowserView):
 
 
 class ConfirmationDeleteSession(SessionMixin, BrowserView):
-    """View name: @@confirmation-delete-session
-    """
+    """View name: @@confirmation-delete-session"""
 
     no_splash = True
 
@@ -536,8 +646,7 @@ class ConfirmationDeleteSession(SessionMixin, BrowserView):
 
 
 class ConfirmationArchiveSession(SessionMixin, BrowserView):
-    """View name: @@confirmation-archive-session
-    """
+    """View name: @@confirmation-archive-session"""
 
     no_splash = True
 
@@ -550,8 +659,7 @@ class ConfirmationArchiveSession(SessionMixin, BrowserView):
 
 
 class ArchiveSession(SessionMixin, BrowserView):
-    """View name: @@archive-session
-    """
+    """View name: @@archive-session"""
 
     def notify_modified(self):
         notify(ObjectModifiedEvent(self.context.session))
@@ -576,8 +684,7 @@ class ArchiveSession(SessionMixin, BrowserView):
 
 
 class CloneSession(SessionMixin, BrowserView):
-    """View name: @@confirmation-clone-session
-    """
+    """View name: @@confirmation-clone-session"""
 
     def get_cloned_session(self):
         sql_session = Session
@@ -650,8 +757,7 @@ class CloneSession(SessionMixin, BrowserView):
         return new_session
 
     def clone(self):
-        """ Clone this session and redirect to the start view
-        """
+        """Clone this session and redirect to the start view"""
         new_session = self.get_cloned_session()
         api.portal.show_message(
             _("The risk assessment has been cloned"), self.request, "success"
@@ -666,8 +772,7 @@ class PublicationMenu(SessionMixin, BrowserView):
     @property
     @memoize_contextless
     def portal(self):
-        """ The currently authenticated account
-        """
+        """The currently authenticated account"""
         return api.portal.get()
 
     def redirect(self):
@@ -675,21 +780,18 @@ class PublicationMenu(SessionMixin, BrowserView):
         return self.request.response.redirect(target)
 
     def reset_date(self):
-        """ Reset the session date to now
-        """
+        """Reset the session date to now"""
         session = self.context.session
         session.published = datetime.now()
         session.last_publisher = get_current_account()
         return self.redirect()
 
     def set_date(self):
-        """ Set the session date to now
-        """
+        """Set the session date to now"""
         return self.reset_date()
 
     def unset_date(self):
-        """ Unset the session date
-        """
+        """Unset the session date"""
         session = self.context.session
         session.published = None
         session.last_publisher = None
@@ -744,7 +846,7 @@ class ActionPlanView(SessionMixin, BrowserView):
         return self.webhelpers.country == "it"
 
     def __call__(self):
-        """ Render the page only if the user has edit rights,
+        """Render the page only if the user has edit rights,
         otherwise redirect to the start page of the session.
         """
         if not self.webhelpers.can_edit_session:
@@ -753,6 +855,10 @@ class ActionPlanView(SessionMixin, BrowserView):
             )
         if self.webhelpers.redirectOnSurveyUpdate():
             return
+        if self.webhelpers.integrated_action_plan:
+            return self.request.response.redirect(
+                self.context.absolute_url() + "/@@report"
+            )
         utils.setLanguage(self.request, self.survey, self.survey.language)
         return super(ActionPlanView, self).__call__()
 
@@ -794,8 +900,7 @@ class Report(SessionMixin, BrowserView):
 
 
 class Status(SessionMixin, BrowserView, _StatusHelper):
-    """Show survey status information.
-    """
+    """Show survey status information."""
 
     variation_class = "variation-risk-assessment"
 
@@ -846,8 +951,8 @@ class Status(SessionMixin, BrowserView, _StatusHelper):
             self.session_title = None
 
     def getStatus(self):
-        """ Gather a list of the modules and locations in this survey as well
-            as data around their state of completion.
+        """Gather a list of the modules and locations in this survey as well
+        as data around their state of completion.
         """
         session = Session()
         total_ok = 0
@@ -953,8 +1058,8 @@ class Status(SessionMixin, BrowserView, _StatusHelper):
 
 
 class RisksOverview(Status):
-    """ Implements the "Overview of Risks" report, see #10967
-    """
+    """Implements the "Overview of Risks" report, see #10967"""
+
     label = _("Overview of risks")
 
     def is_skipped_from_risk_list(self, risk):
@@ -963,8 +1068,8 @@ class RisksOverview(Status):
 
 
 class MeasuresOverview(Status):
-    """ Implements the "Overview of Measures" report, see #10967
-    """
+    """Implements the "Overview of Measures" report, see #10967"""
+
     label = _("Overview of measures")
 
     def update(self):
