@@ -13,7 +13,6 @@ import unittest
 
 
 class EvaluationViewTests(unittest.TestCase):
-
     def EvaluationView(self, **kw):
         """
         Note: the EvaluationView does not exist as a separate view any more.
@@ -29,19 +28,22 @@ class EvaluationViewTests(unittest.TestCase):
     def reply(self, freq, effect, prob=None):
         if prob is None:  # French
             return {
-                "frequency": IFr['default_frequency'
-                                 ].vocabulary.getTermByToken(freq).value,
-                "severity": IFr['default_severity']
-                .vocabulary.getTermByToken(effect).value,
+                "frequency": IFr["default_frequency"]
+                .vocabulary.getTermByToken(freq)
+                .value,
+                "severity": IFr["default_severity"]
+                .vocabulary.getTermByToken(effect)
+                .value,
             }
         else:  # Kinney
             return {
-                "frequency": IKi['default_frequency'
-                                 ].vocabulary.getTermByToken(freq).value,
-                "effect": IKi['default_effect'
-                              ].vocabulary.getTermByToken(effect).value,
-                "probability": IKi['default_probability']
-                .vocabulary.getTermByToken(prob).value,
+                "frequency": IKi["default_frequency"]
+                .vocabulary.getTermByToken(freq)
+                .value,
+                "effect": IKi["default_effect"].vocabulary.getTermByToken(effect).value,
+                "probability": IKi["default_probability"]
+                .vocabulary.getTermByToken(prob)
+                .value,
             }
 
     def test_evaluation_algorithm_fallback(self):
@@ -59,98 +61,83 @@ class EvaluationViewTests(unittest.TestCase):
     def test_calculatePriority_kinney_nothing_set(self):
         view = self.EvaluationView()
         risk = self.Risk()
-        risk.evaluation_method = 'calculated'
+        risk.evaluation_method = "calculated"
         with mock.patch(
-            'euphorie.client.browser.risk.evaluation_algorithm',
-            return_value='kinney'
+            "euphorie.client.browser.risk.evaluation_algorithm", return_value="kinney"
         ):
             self.assertEqual(view.calculatePriority(risk, {}), None)
 
     def test_calculatePriority_french_nothing_set(self):
         view = self.EvaluationView()
         risk = self.Risk()
-        risk.evaluation_method = 'calculated'
+        risk.evaluation_method = "calculated"
         with mock.patch(
-            'euphorie.client.browser.risk.evaluation_algorithm',
-            return_value='french'
+            "euphorie.client.browser.risk.evaluation_algorithm", return_value="french"
         ):
             self.assertEqual(view.calculatePriority(risk, {}), None)
 
     def test_calculatePriority_french(self):
         view = self.EvaluationView()
         with mock.patch(
-            'euphorie.client.browser.risk.evaluation_algorithm',
-            return_value='french'
+            "euphorie.client.browser.risk.evaluation_algorithm", return_value="french"
         ):
             risk = self.Risk()
-            risk.evaluation_method = 'calculated'
+            risk.evaluation_method = "calculated"
             # Risks with weak severity are always low priority
             for freq in ["rare", "not-often", "often", "regularly"]:
                 self.assertEqual(
-                    view.calculatePriority(risk, self.reply(freq, "weak")),
-                    "low"
+                    view.calculatePriority(risk, self.reply(freq, "weak")), "low"
                 )
             # High priority items
             self.assertEqual(
-                view.calculatePriority(risk, self.reply("often", "severe")),
-                "high"
+                view.calculatePriority(risk, self.reply("often", "severe")), "high"
             )
             self.assertEqual(
-                view.calculatePriority(
-                    risk, self.reply("often", "very-severe")
-                ), "high"
+                view.calculatePriority(risk, self.reply("often", "very-severe")), "high"
             )
             self.assertEqual(
-                view.calculatePriority(
-                    risk, self.reply("regularly", "severe")
-                ), "high"
+                view.calculatePriority(risk, self.reply("regularly", "severe")), "high"
             )
             self.assertEqual(
-                view.calculatePriority(
-                    risk, self.reply("regularly", "very-severe")
-                ), "high"
+                view.calculatePriority(risk, self.reply("regularly", "very-severe")),
+                "high",
             )
             # Some medium priority items
             self.assertEqual(
-                view.calculatePriority(
-                    risk, self.reply("rare", "very-severe")
-                ), "medium"
+                view.calculatePriority(risk, self.reply("rare", "very-severe")),
+                "medium",
             )
             self.assertEqual(
-                view.calculatePriority(
-                    risk, self.reply("not-often", "not-severe")
-                ), "medium"
+                view.calculatePriority(risk, self.reply("not-often", "not-severe")),
+                "medium",
             )
 
     def test_calculatePriority_kinney(self):
         view = self.EvaluationView()
         risk = self.Risk()
-        risk.evaluation_method = 'calculated'
+        risk.evaluation_method = "calculated"
         with mock.patch(
-            'euphorie.client.browser.risk.evaluation_algorithm',
-            return_value='kinney'
+            "euphorie.client.browser.risk.evaluation_algorithm", return_value="kinney"
         ):
             # Risks with weak severity are always low priority
             for freq in ["almost-never", "regular", "constant"]:
                 self.assertEqual(
-                    view.calculatePriority(
-                        risk, self.reply(freq, "weak", 'small')
-                    ), "low"
+                    view.calculatePriority(risk, self.reply(freq, "weak", "small")),
+                    "low",
                 )
             self.assertEqual(
                 view.calculatePriority(
-                    risk, self.reply("constant", "significant", 'medium')
-                ), "high"
+                    risk, self.reply("constant", "significant", "medium")
+                ),
+                "high",
             )
             self.assertEqual(
-                view.calculatePriority(
-                    risk, self.reply("constant", "high", 'medium')
-                ), "high"
+                view.calculatePriority(risk, self.reply("constant", "high", "medium")),
+                "high",
             )
             self.assertEqual(
-                view.calculatePriority(
-                    risk, self.reply("constant", "weak", 'medium')
-                ), "medium"
+                view.calculatePriority(risk, self.reply("constant", "weak", "medium")),
+                "medium",
             )
 
 
@@ -203,7 +190,11 @@ class TestRiskImageDownloadUpload(EuphorieIntegrationTestCase):
             self.assertTrue(view().startswith(b"GIF"))
             self.assertDictEqual(
                 view.request.response.headers,
-                {"content-length": "168", "content-type": "image/gif"},
+                {
+                    "accept-ranges": "bytes",
+                    "content-length": "168",
+                    "content-type": "image/gif",
+                },
             )
 
             # Check that we can crop and scale the image on the fly
@@ -211,5 +202,9 @@ class TestRiskImageDownloadUpload(EuphorieIntegrationTestCase):
             self.assertTrue(view().startswith(b"\x89PNG"))
             self.assertDictEqual(
                 view.request.response.headers,
-                {"content-length": "6971", "content-type": "image/png"},
+                {
+                    "accept-ranges": "bytes",
+                    "content-length": "6971",
+                    "content-type": "image/png",
+                },
             )
