@@ -13,7 +13,6 @@ import datetime
 
 
 class AccountSettingsTests(EuphorieFunctionalTestCase):
-
     def setUp(self):
         super(AccountSettingsTests, self).setUp()
         self.loginAsPortalOwner()
@@ -28,13 +27,9 @@ class AccountSettingsTests(EuphorieFunctionalTestCase):
         browser.open("http://nohost/plone/client/nl/account-settings")
         browser.getControl(name="form.widgets.old_password").value = "wrong"
         browser.getControl(name="form.widgets.new_password").value = "secret"
-        browser.getControl(
-            name="form.widgets.new_password.confirm"
-        ).value = "secret"
+        browser.getControl(name="form.widgets.new_password.confirm").value = "secret"
         browser.getControl(name="form.buttons.save").click()
-        self.assertEqual(
-            browser.url, "http://nohost/plone/client/nl/account-settings"
-        )
+        self.assertEqual(browser.url, "http://nohost/plone/client/nl/account-settings")
         self.assertTrue("Invalid password" in browser.contents)
 
     def testNoNewPassword(self):
@@ -42,28 +37,19 @@ class AccountSettingsTests(EuphorieFunctionalTestCase):
         browser.open("http://nohost/plone/client/nl/account-settings")
         browser.getControl(name="form.widgets.old_password").value = "guest"
         browser.getControl(name="form.buttons.save").click()
-        self.assertEqual(
-            browser.url, "http://nohost/plone/client/nl/account-settings"
-        )
-        self.assertTrue(
-            "There were no changes to be saved." in browser.contents
-        )
+        self.assertEqual(browser.url, "http://nohost/plone/client/nl/account-settings")
+        self.assertTrue("There were no changes to be saved." in browser.contents)
 
     def testPasswordMismatch(self):
         browser = self.browser
         browser.open("http://nohost/plone/client/nl/account-settings")
         browser.getControl(name="form.widgets.old_password").value = "guest"
         browser.getControl(name="form.widgets.new_password").value = "secret"
-        browser.getControl(
-            name="form.widgets.new_password.confirm"
-        ).value = "secret2"
+        browser.getControl(name="form.widgets.new_password.confirm").value = "secret2"
         browser.getControl(name="form.buttons.save").click()
-        self.assertEqual(
-            browser.url, "http://nohost/plone/client/nl/account-settings"
-        )
+        self.assertEqual(browser.url, "http://nohost/plone/client/nl/account-settings")
         self.assertTrue(
-            "Password doesn't compare with confirmation value" in
-            browser.contents
+            "Password doesn't compare with confirmation value" in browser.contents
         )
 
     def testUpdatePassword(self):
@@ -71,21 +57,15 @@ class AccountSettingsTests(EuphorieFunctionalTestCase):
         browser.open("http://nohost/plone/client/nl/account-settings")
         browser.getControl(name="form.widgets.old_password").value = "guest"
         browser.getControl(name="form.widgets.new_password").value = "secret"
-        browser.getControl(
-            name="form.widgets.new_password.confirm"
-        ).value = "secret"
+        browser.getControl(name="form.widgets.new_password.confirm").value = "secret"
         browser.handleErrors = False
         browser.getControl(name="form.buttons.save").click()
-        self.assertEqual(
-            browser.url,
-            "http://nohost/plone/client/nl/account-settings"
-        )
+        self.assertEqual(browser.url, "http://nohost/plone/client/nl/account-settings")
         account = Session.query(Account).first()
         self.assertTrue(account.verify_password("secret"))
 
 
 class AccountDeleteTests(EuphorieFunctionalTestCase):
-
     def setUp(self):
         super(AccountDeleteTests, self).setUp()
         self.loginAsPortalOwner()
@@ -99,18 +79,14 @@ class AccountDeleteTests(EuphorieFunctionalTestCase):
         browser = self.browser
         browser.handleErrors = False
         browser.open("http://nohost/plone/client/nl/account-delete")
-        self.assertEqual(
-            browser.getControl(name="form.widgets.password").value, ""
-        )
+        self.assertEqual(browser.getControl(name="form.widgets.password").value, "")
 
     def testInvalidPassword(self):
         browser = self.browser
         browser.open("http://nohost/plone/client/nl/account-delete")
         browser.getControl(name="form.widgets.password").value = "secret"
         browser.getControl(name="form.buttons.delete").click()
-        self.assertEqual(
-            browser.url, "http://nohost/plone/client/nl/account-delete"
-        )
+        self.assertEqual(browser.url, "http://nohost/plone/client/nl/account-delete")
         self.assertTrue("Invalid password" in browser.contents)
 
     def testDelete(self):
@@ -118,13 +94,11 @@ class AccountDeleteTests(EuphorieFunctionalTestCase):
         browser.open("http://nohost/plone/client/nl/account-delete")
         browser.getControl(name="form.widgets.password").value = "guest"
         browser.getControl(name="form.buttons.delete").click()
-        self.assertTrue(
-            browser.url.startswith("http://nohost/plone/client/nl"))
+        self.assertTrue(browser.url.startswith("http://nohost/plone/client/nl"))
         self.assertEqual(Session.query(Account).count(), 0)
 
 
 class NewEmailTests(EuphorieFunctionalTestCase):
-
     def setUp(self):
         super(NewEmailTests, self).setUp()
         self.loginAsPortalOwner()
@@ -144,31 +118,23 @@ class NewEmailTests(EuphorieFunctionalTestCase):
         browser = self.browser
         browser.handleErrors = False
         browser.open("http://nohost/plone/client/nl/new-email")
-        self.assertEqual(
-            browser.getControl(name="form.widgets.password").value, ""
-        )
+        self.assertEqual(browser.getControl(name="form.widgets.password").value, "")
 
     def testNoChange(self):
         browser = self.browser
         browser.open("http://nohost/plone/client/nl/new-email")
         browser.getControl(name="form.widgets.password").value = "guest"
         browser.getControl(name="form.buttons.save").click()
-        self.assertEqual(
-            browser.url, "http://nohost/plone/client/nl/new-email"
-        )
+        self.assertEqual(browser.url, "http://nohost/plone/client/nl/new-email")
         self.assertTrue("Required input is missing." in browser.contents)
 
     def testInvalidPassword(self):
         browser = self.browser
         browser.open("http://nohost/plone/client/nl/new-email")
-        browser.getControl(
-            name="form.widgets.loginname"
-        ).value = "jane@example.com"
+        browser.getControl(name="form.widgets.loginname").value = "jane@example.com"
         browser.getControl(name="form.widgets.password").value = "secret"
         browser.getControl(name="form.buttons.save").click()
-        self.assertEqual(
-            browser.url, "http://nohost/plone/client/nl/new-email"
-        )
+        self.assertEqual(browser.url, "http://nohost/plone/client/nl/new-email")
         self.assertTrue("Invalid password" in browser.contents)
 
     def testInvalidEmail(self):
@@ -177,9 +143,7 @@ class NewEmailTests(EuphorieFunctionalTestCase):
         browser.getControl(name="form.widgets.password").value = "guest"
         browser.getControl(name="form.widgets.loginname").value = "one two"
         browser.getControl(name="form.buttons.save").click()
-        self.assertEqual(
-            browser.url, "http://nohost/plone/client/nl/new-email"
-        )
+        self.assertEqual(browser.url, "http://nohost/plone/client/nl/new-email")
         self.assertTrue("Not a valid email address" in browser.contents)
 
     def testDuplicateEmail(self):
@@ -188,13 +152,9 @@ class NewEmailTests(EuphorieFunctionalTestCase):
         commit()
         browser.open("http://nohost/plone/client/nl/new-email")
         browser.getControl(name="form.widgets.password").value = "guest"
-        browser.getControl(
-            name="form.widgets.loginname"
-        ).value = "jane@example.com"
+        browser.getControl(name="form.widgets.loginname").value = "jane@example.com"
         browser.getControl(name="form.buttons.save").click()
-        self.assertEqual(
-            browser.url, "http://nohost/plone/client/nl/new-email"
-        )
+        self.assertEqual(browser.url, "http://nohost/plone/client/nl/new-email")
         self.assertTrue("address is not available" in browser.contents)
 
     def testChange(self):
@@ -202,13 +162,9 @@ class NewEmailTests(EuphorieFunctionalTestCase):
         browser.handleErrors = False
         browser.open("http://nohost/plone/client/nl/new-email")
         browser.getControl(name="form.widgets.password").value = "guest"
-        browser.getControl(
-            name="form.widgets.loginname"
-        ).value = "discard@simplon.biz"
+        browser.getControl(name="form.widgets.loginname").value = "discard@simplon.biz"
         browser.getControl(name="form.buttons.save").click()
-        self.assertEqual(
-            browser.url, "http://nohost/plone/client/nl/"
-        )
+        self.assertEqual(browser.url, "http://nohost/plone/client/nl/")
         self.assertTrue("Please confirm your new email" in browser.contents)
         self.assertTrue("discard@simplon.biz" in browser.contents)
         self.assertEqual(Session.query(AccountChangeRequest).count(), 1)
@@ -217,8 +173,8 @@ class NewEmailTests(EuphorieFunctionalTestCase):
         self.assertTrue(user.change_request is not None)
         self.assertEqual(user.change_request.value, "discard@simplon.biz")
         self.assertTrue(
-            user.change_request.expires >
-            datetime.datetime.now() + datetime.timedelta(days=6)
+            user.change_request.expires
+            > datetime.datetime.now() + datetime.timedelta(days=6)
         )
 
         self.assertEqual(len(self.email_send), 1)
@@ -230,16 +186,12 @@ class NewEmailTests(EuphorieFunctionalTestCase):
         browser.handleErrors = False
         browser.open("http://nohost/plone/client/nl/new-email")
         browser.getControl(name="form.widgets.password").value = "guest"
-        browser.getControl(
-            name="form.widgets.loginname"
-        ).value = "discard@simplon.biz"
+        browser.getControl(name="form.widgets.loginname").value = "discard@simplon.biz"
         browser.getControl(name="form.buttons.save").click()
         first_key = Session.query(AccountChangeRequest.id).first()[0]
         browser.open("http://nohost/plone/client/nl/new-email")
         browser.getControl(name="form.widgets.password").value = "guest"
-        browser.getControl(
-            name="form.widgets.loginname"
-        ).value = "discard@simplon.biz"
+        browser.getControl(name="form.widgets.loginname").value = "discard@simplon.biz"
         browser.getControl(name="form.buttons.save").click()
         second_key = Session.query(AccountChangeRequest.id).first()[0]
         self.assertNotEqual(first_key, second_key)
@@ -249,16 +201,13 @@ class NewEmailTests(EuphorieFunctionalTestCase):
         browser.handleErrors = False
         browser.open("http://nohost/plone/client/nl/new-email")
         browser.getControl(name="form.widgets.password").value = "guest"
-        browser.getControl(
-            name="form.widgets.loginname"
-        ).value = "DISCARD@sImplOn.biz"
+        browser.getControl(name="form.widgets.loginname").value = "DISCARD@sImplOn.biz"
         browser.getControl(name="form.buttons.save").click()
         request = Session.query(AccountChangeRequest).first()
-        self.assertEqual(request.value, 'discard@simplon.biz')
+        self.assertEqual(request.value, "discard@simplon.biz")
 
 
 class ChangeEmailTests(EuphorieFunctionalTestCase):
-
     def testMissingKey(self):
         browser = self.get_browser()
         browser.open("http://nohost/plone/client/confirm-change")
@@ -272,15 +221,11 @@ class ChangeEmailTests(EuphorieFunctionalTestCase):
         account.change_request = AccountChangeRequest(
             id="X" * 16,
             value="new-login",
-            expires=datetime.datetime.now() + datetime.timedelta(1)
+            expires=datetime.datetime.now() + datetime.timedelta(1),
         )
         Session.add(account)
         Session.flush()
         browser = self.get_browser()
-        browser.open(
-            "http://nohost/plone/client/confirm-change?key=XXXXXXXXXXXXXXXX"
-        )
+        browser.open("http://nohost/plone/client/confirm-change?key=XXXXXXXXXXXXXXXX")
         self.assertEqual(browser.url, "http://nohost/plone/client/")
-        self.assertEqual(
-            Session.query(Account.loginname).first()[0], "new-login"
-        )
+        self.assertEqual(Session.query(Account.loginname).first()[0], "new-login")
