@@ -1,9 +1,18 @@
-import re
-from zope.interface import implements
+"""
+Colour
+------
+
+Defines a colour field, with a validator.
+"""
+
+from .. import MessageFactory as _
 from zope import schema
-from zope.schema.interfaces import ValidationError
+from zope.interface import implements
 from zope.schema.interfaces import IBytesLine
-from euphorie.content import MessageFactory as _
+from zope.schema.interfaces import ValidationError
+
+import re
+
 
 VALID_COLOUR = re.compile(r"^#?[0-9a-f]+$")
 
@@ -17,8 +26,7 @@ class IColour(IBytesLine):
 
 
 class Colour(schema.BytesLine):
-    """Colour selector field.
-    """
+    """Colour selector field."""
 
     implements(IColour)
 
@@ -32,9 +40,8 @@ class Colour(schema.BytesLine):
     def fromUnicode(self, u):
         v = str(u)
         if not v.startswith("#"):
-            v="#%s" % v
+            v = "#%s" % v
 
         self.validate(v)
 
         return v
-
