@@ -14,7 +14,7 @@ from euphorie.content.country import ICountry
 from euphorie.content.user import IUser
 from euphorie.content.user import UserProvider
 from five import grok
-from plone.directives import dexterity
+from plone.dexterity.content import Item
 from plone.directives import form
 from plone.indexer import indexer
 from plone.uuid.interfaces import IAttributeUUID
@@ -27,13 +27,13 @@ grok.templatedir("templates")
 
 
 class ICountryManager(form.Schema, IUser):
-    """A country manager is responsible for managing sectors in their country.
-    """
+    """A country manager is responsible for managing sectors in their country."""
 
 
-class CountryManager(dexterity.Item):
+class CountryManager(Item):
     """A country manager."""
-    portal_type = 'euphorie.countrymanager'
+
+    portal_type = "euphorie.countrymanager"
     implements(ICountryManager, IAttributeUUID)
 
     locked = False
@@ -45,11 +45,8 @@ class CountryManager(dexterity.Item):
 
 @indexer(ICountryManager)
 def SearchableTextIndexer(obj):
-    """ Index the title, contact_name and contact_email
-    """
-    return " ".join([obj.title,
-                     obj.contact_name,
-                     obj.contact_email])
+    """Index the title, contact_name and contact_email"""
+    return " ".join([obj.title, obj.contact_name, obj.contact_email])
 
 
 class CountryManagerLocalRoleProvider(grok.Adapter):
@@ -58,6 +55,7 @@ class CountryManagerLocalRoleProvider(grok.Adapter):
     This local role provider gives country managers the Administrator
     role within their country.
     """
+
     grok.context(ICountry)
     grok.implements(ILocalRoleProvider)
     grok.name("euphorie.countrymanager")
@@ -72,24 +70,29 @@ class CountryManagerLocalRoleProvider(grok.Adapter):
         if not ICountryManager.providedBy(user):
             return ()
 
-        if user.getPhysicalPath()[:-1] == \
-                aq_inner(self.context).getPhysicalPath():
-            return ("CountryManager", "Editor", "Contributor", "Reader",
-                    "Reviewer")
+        if user.getPhysicalPath()[:-1] == aq_inner(self.context).getPhysicalPath():
+            return ("CountryManager", "Editor", "Contributor", "Reader", "Reviewer")
         else:
             return ()
 
     def getAllRoles(self):
-        managers = [UserProvider(manager) for manager in self.context.values()
-                  if ICountryManager.providedBy(manager)]
-        return [(manager.getUserId(),
-                 ("CountryyManager", "Editor", "Contributor", "Reader",
-                     "Reviewer")) for manager in managers]
+        managers = [
+            UserProvider(manager)
+            for manager in self.context.values()
+            if ICountryManager.providedBy(manager)
+        ]
+        return [
+            (
+                manager.getUserId(),
+                ("CountryyManager", "Editor", "Contributor", "Reader", "Reviewer"),
+            )
+            for manager in managers
+        ]
 
 
 class View(grok.View):
-    """ View name: @@nuplone-view
-    """
+    """View name: @@nuplone-view"""
+
     grok.context(ICountryManager)
     grok.require("zope2.View")
     grok.layer(NuPloneSkin)
