@@ -1,12 +1,21 @@
+"""
+Sector Container
+----------------
+
+A Sector Container provides the overview of all countries.
+
+https://admin.oiraproject.eu/sectors
+"""
 from Acquisition import aq_inner
-from zope.interface import implements
-from five import grok
-from plone.directives import form
-from plone.directives import dexterity
-from plone.app.dexterity.behaviors.metadata import IBasic
 from euphorie.content.behaviour.richdescription import IRichDescription
 from euphorie.content.utils import summarizeCountries
+from five import grok
+from plone.app.dexterity.behaviors.metadata import IBasic
+from plone.dexterity.content import Container
+from plone.directives import form
 from plonetheme.nuplone.skin.interfaces import NuPloneSkin
+from zope.interface import implements
+
 
 grok.templatedir("templates")
 
@@ -15,8 +24,7 @@ class ISectorContainer(form.Schema, IRichDescription, IBasic):
     """Container for all sectors."""
 
 
-
-class SectorContainer(dexterity.Container):
+class SectorContainer(Container):
     implements(ISectorContainer)
 
     def _canCopy(self, op=0):
@@ -24,7 +32,6 @@ class SectorContainer(dexterity.Container):
         return False
 
 
-
 class View(grok.View):
     grok.context(ISectorContainer)
     grok.require("zope2.View")
@@ -33,5 +40,4 @@ class View(grok.View):
     grok.name("nuplone-view")
 
     def update(self):
-        self.countries=summarizeCountries(aq_inner(self.context), self.request)
-
+        self.countries = summarizeCountries(aq_inner(self.context), self.request)
