@@ -7,36 +7,38 @@ A Survey Group is a container for several Survey versions.
 https://admin.oiraproject.eu/sectors/eu/eu-private-security/private-security-eu
 """
 
-import datetime
-import logging
-import urllib
+from .. import MessageFactory as _
 from Acquisition import aq_inner
 from Acquisition import aq_parent
-from OFS.event import ObjectClonedEvent
-from ZODB.POSException import ConflictError
-from z3c.form.interfaces import IEditForm
-from zope import schema
-from zope.component import getUtility
-from zope.event import notify
-from zope.interface import implements
-from zope.schema.vocabulary import SimpleVocabulary
-from zope.schema.vocabulary import SimpleTerm
-from zope.lifecycleevent.interfaces import IObjectRemovedEvent
-from Products.CMFCore.interfaces import IActionSucceededEvent
-from Products.CMFCore.interfaces import ISiteRoot
-from Products.CMFCore.utils import getToolByName
-from Products.statusmessages.interfaces import IStatusMessage
-from .. import MessageFactory as _
 from euphorie.content.interfaces import SurveyUnpublishEvent
 from euphorie.content.survey import ISurvey
 from five import grok
-from Products.Five.browser.pagetemplatefile import ViewPageTemplateFile
-from zope.i18n import translate
+from OFS.event import ObjectClonedEvent
 from plone.app.dexterity.behaviors.metadata import IBasic
+from plone.dexterity.content import Container
 from plone.dexterity.utils import createContentInContainer
 from plone.directives import dexterity
 from plone.directives import form
 from plonetheme.nuplone.skin.interfaces import NuPloneSkin
+from Products.CMFCore.interfaces import IActionSucceededEvent
+from Products.CMFCore.interfaces import ISiteRoot
+from Products.CMFCore.utils import getToolByName
+from Products.Five.browser.pagetemplatefile import ViewPageTemplateFile
+from Products.statusmessages.interfaces import IStatusMessage
+from z3c.form.interfaces import IEditForm
+from ZODB.POSException import ConflictError
+from zope import schema
+from zope.component import getUtility
+from zope.event import notify
+from zope.i18n import translate
+from zope.interface import implements
+from zope.lifecycleevent.interfaces import IObjectRemovedEvent
+from zope.schema.vocabulary import SimpleTerm
+from zope.schema.vocabulary import SimpleVocabulary
+
+import datetime
+import logging
+import urllib
 
 
 grok.templatedir("templates")
@@ -46,40 +48,49 @@ log = logging.getLogger(__name__)
 
 class ISurveyGroup(form.Schema, IBasic):
     title = schema.TextLine(
-            title=_("label_title", default=u"Title"),
-            description=_("help_surveygroup_title",
-                default=u"The title of this OiRA Tool. This title is used in "
-                        u"the OiRA Tool overview in the clients."),
-            required=True)
+        title=_("label_title", default=u"Title"),
+        description=_(
+            "help_surveygroup_title",
+            default=u"The title of this OiRA Tool. This title is used in "
+            u"the OiRA Tool overview in the clients.",
+        ),
+        required=True,
+    )
     form.order_before(title="*")
 
     form.omitted("description")
 
     obsolete = schema.Bool(
-            title=_("label_survey_obsolete",
-                default=u"Obsolete OiRA tool"),
-            description=_("help_survey_obsolete",
-                default=u"This OiRA Tool is obsolete; it has been retired or "
-                        u"replaced with another OiRA Tool."),
-            default=False,
-            required=False)
+        title=_("label_survey_obsolete", default=u"Obsolete OiRA tool"),
+        description=_(
+            "help_survey_obsolete",
+            default=u"This OiRA Tool is obsolete; it has been retired or "
+            u"replaced with another OiRA Tool.",
+        ),
+        default=False,
+        required=False,
+    )
 
-    form.omitted(IEditForm, 'evaluation_algorithm')
+    form.omitted(IEditForm, "evaluation_algorithm")
     evaluation_algorithm = schema.Choice(
-            title=_("label_survey_evaluation_algorithm",
-                default=u"Evaluation algorithm"),
-            vocabulary=SimpleVocabulary([
-                SimpleTerm(u"kinney",
-                    title=_("algorithm_kinney",
-                        default=u"Standard three criteria")),
-                SimpleTerm(u"french",
-                    title=_("french", default=u"Simplified two criteria")),
-                ]),
-            default=u"kinney",
-            required=True)
+        title=_("label_survey_evaluation_algorithm", default=u"Evaluation algorithm"),
+        vocabulary=SimpleVocabulary(
+            [
+                SimpleTerm(
+                    u"kinney",
+                    title=_("algorithm_kinney", default=u"Standard three criteria"),
+                ),
+                SimpleTerm(
+                    u"french", title=_("french", default=u"Simplified two criteria")
+                ),
+            ]
+        ),
+        default=u"kinney",
+        required=True,
+    )
 
 
-class SurveyGroup(dexterity.Container):
+class SurveyGroup(Container):
     grok.name("euphorie.surveygroup")
     implements(ISurveyGroup)
 
@@ -108,6 +119,7 @@ class AddForm(dexterity.AddForm):
     the :obj:`ITemplateSchema` schema, which allows users to pick a template
     survey to use as a basis for the new survey.
     """
+
     grok.context(ISurveyGroup)
     grok.name("euphorie.surveygroup")
     grok.require("euphorie.content.AddNewRIEContent")
@@ -126,64 +138,64 @@ class AddForm(dexterity.AddForm):
         catalog = getToolByName(self.context, "portal_catalog")
         startPath = "%s/sectors" % "/".join(site.getPhysicalPath())
         startPathDepth = startPath.count("/") + 1
-        query = \
-            {"path": {'query': startPath,
-                      'depth': 4,
-                    'navtree': True},
-             "portal_type": ["euphorie.country",
-                             "euphorie.sector",
-                             "euphorie.surveygroup",
-                             "euphorie.survey"],
-             "sort_on": "path",
-             "sort_order": "asc"}
+        query = {
+            "path": {"query": startPath, "depth": 4, "navtree": True},
+            "portal_type": [
+                "euphorie.country",
+                "euphorie.sector",
+                "euphorie.surveygroup",
+                "euphorie.survey",
+            ],
+            "sort_on": "path",
+            "sort_order": "asc",
+        }
         tree = {}
         for brain in catalog.searchResults(query):
             path = brain.getPath().split("/")[startPathDepth:]
             if brain.portal_type == "euphorie.country":
-                tree[brain.id] = dict(id=brain.id,
-                                    title=brain.Title,
-                                    path=brain.getPath(),
-                                    sectors={})
+                tree[brain.id] = dict(
+                    id=brain.id, title=brain.Title, path=brain.getPath(), sectors={}
+                )
             elif brain.portal_type == "euphorie.sector":
                 country = tree[path[0]]
-                country["sectors"][brain.id] = dict(id=brain.id,
-                                                    title=brain.Title,
-                                                    path=brain.getPath(),
-                                                    groups={})
+                country["sectors"][brain.id] = dict(
+                    id=brain.id, title=brain.Title, path=brain.getPath(), groups={}
+                )
             elif brain.portal_type == "euphorie.surveygroup":
                 country = tree[path[0]]
                 sector = country["sectors"][path[1]]
-                sector["groups"][brain.id] = dict(id=brain.id,
-                                                title=brain.Title,
-                                                path=brain.getPath(),
-                                                surveys={})
+                sector["groups"][brain.id] = dict(
+                    id=brain.id, title=brain.Title, path=brain.getPath(), surveys={}
+                )
             elif brain.portal_type == "euphorie.survey":
                 country = tree[path[0]]
                 sector = country["sectors"][path[1]]
                 group = sector["groups"][path[2]]
-                group["surveys"][brain.id] = dict(id=brain.id,
-                                                title=brain.Title,
-                                                path=brain.getPath(),
-                                                url=brain.getURL())
-        my_sector_path = tree[self.my_country]["sectors"][
-                self.my_sector]["path"]
+                group["surveys"][brain.id] = dict(
+                    id=brain.id,
+                    title=brain.Title,
+                    path=brain.getPath(),
+                    url=brain.getURL(),
+                )
+        my_sector_path = tree[self.my_country]["sectors"][self.my_sector]["path"]
         countries = sorted(tree.values(), key=lambda x: x["title"])
         self.my_group = None
         for country in countries:
-            country["sectors"] = sectors = \
-                sorted(country["sectors"].values(), key=lambda x: x["title"])
+            country["sectors"] = sectors = sorted(
+                country["sectors"].values(), key=lambda x: x["title"]
+            )
 
             for sector in sectors:
-                sector["groups"] = groups = \
-                    sorted(sector["groups"].values(), key=lambda x: x["title"])
+                sector["groups"] = groups = sorted(
+                    sector["groups"].values(), key=lambda x: x["title"]
+                )
 
                 if sector["path"] == my_sector_path and sector["groups"]:
                     self.my_group = sector["groups"][0]["id"]
                 for group in groups:
                     group["surveys"] = sorted(
-                                        group["surveys"].values(),
-                                        key=lambda x: x["title"]
-                                        )
+                        group["surveys"].values(), key=lambda x: x["title"]
+                    )
 
                 sector["groups"] = [g for g in groups if g["surveys"]]
             country["sectors"] = [s for s in sectors if s["groups"]]
@@ -200,20 +212,24 @@ class AddForm(dexterity.AddForm):
         copy = source._getCopy(target)
 
         today = datetime.date.today()
-        title = self.request.locale.dates.getFormatter("date", length="long")\
-                .format(datetime.date.today())
+        title = self.request.locale.dates.getFormatter("date", length="long").format(
+            datetime.date.today()
+        )
         copy.id = today.isoformat()
         copy.title = title
         source_algorithm = aq_parent(source).evaluation_algorithm
         target_algorithm = self.request.form.get(
-            'form.widgets.evaluation_algorithm', [source_algorithm]).pop()
+            "form.widgets.evaluation_algorithm", [source_algorithm]
+        ).pop()
         target.evaluation_algorithm = target_algorithm
         target._setObject(copy.id, copy)
         if source_algorithm != target_algorithm:
-            from euphorie.content.risk import IRisk
             from euphorie.content.risk import EnsureInterface
+            from euphorie.content.risk import IRisk
+
             risks = [
-                item for (id, item) in target.ZopeFind(target, search_sub=1)
+                item
+                for (id, item) in target.ZopeFind(target, search_sub=1)
                 if IRisk.providedBy(item)
             ]
             for risk in risks:
@@ -256,12 +272,11 @@ class AddForm(dexterity.AddForm):
             self.immediate_view = survey.absolute_url()
         else:
             title = translate(
-                        _("survey_default_title", default=u"Standard"),
-                        context=self.request)
+                _("survey_default_title", default=u"Standard"), context=self.request
+            )
 
             obj = aq_inner(self.context)[obj.id]
-            survey = createContentInContainer(
-                            obj, "euphorie.survey", title=title)
+            survey = createContentInContainer(obj, "euphorie.survey", title=title)
 
             self.immediate_view = survey.absolute_url()
         return obj
@@ -279,9 +294,10 @@ class Unpublish(grok.View):
 
         wt = getToolByName(context, "portal_workflow")
         if wt.getInfoFor(published_survey, "review_state") != "published":
-            log.warning("Trying to unpublish survey %s which is not marked as "
-                        "published",
-                        "/".join(published_survey.getPhysicalPath()))
+            log.warning(
+                "Trying to unpublish survey %s which is not marked as " "published",
+                "/".join(published_survey.getPhysicalPath()),
+            )
         else:
             wt.doActionFor(published_survey, "retract")
         notify(SurveyUnpublishEvent(published_survey))
@@ -291,12 +307,19 @@ class Unpublish(grok.View):
         flash = IStatusMessage(self.request).addStatusMessage
         if action == "unpublish":
             self.unpublish()
-            flash(_("message_unpublish_success",
-                default=u"This OiRA Tool is now no longer available in "
-                        u"the client."), "success")
+            flash(
+                _(
+                    "message_unpublish_success",
+                    default=u"This OiRA Tool is now no longer available in "
+                    u"the client.",
+                ),
+                "success",
+            )
         else:
-            flash(_("message_unpublish_cancel",
-                default=u"Cancelled unpublish action."), "notice")
+            flash(
+                _("message_unpublish_cancel", default=u"Cancelled unpublish action."),
+                "notice",
+            )
 
         context = aq_inner(self.context)
         self.request.response.redirect(context.absolute_url())
@@ -319,14 +342,16 @@ class VersionCommand(grok.View):
         survey_id = self.request.form.get("survey")
         response = self.request.response
         if action == "publish":
-            response.redirect("%s/%s/@@publish" %
-                    (surveygroup.absolute_url(), survey_id))
+            response.redirect(
+                "%s/%s/@@publish" % (surveygroup.absolute_url(), survey_id)
+            )
         elif action == "unpublish":
             response.redirect("%s/@@unpublish" % surveygroup.absolute_url())
         elif action == "clone":
-            response.redirect("%s/++add++euphorie.survey?%s" %
-                    (surveygroup.absolute_url(),
-                     urllib.urlencode(dict(survey=survey_id))))
+            response.redirect(
+                "%s/++add++euphorie.survey?%s"
+                % (surveygroup.absolute_url(), urllib.urlencode(dict(survey=survey_id)))
+            )
         else:
             log.error("Invalid version command action: %r", action)
 
