@@ -4,14 +4,17 @@ from Acquisition import aq_inner
 from Acquisition import aq_parent
 from euphorie.client.browser.webhelpers import WebHelpers
 from euphorie.client.model import Account
+from euphorie.client.model import ActionPlan
 from euphorie.client.model import Session
 from euphorie.client.model import SurveySession
+from euphorie.client.model import SurveyTreeItem
 from euphorie.content.api.entry import access_api
 from euphorie.content.countrymanager import ICountryManager
 from euphorie.content.risk import EnsureInterface
 from euphorie.content.risk import IRisk
 from plone import api
 from plone.dexterity.interfaces import IDexterityContainer
+from plone.memoize.instance import memoize
 from plone.memoize.view import memoize_contextless
 from plone.protect.interfaces import IDisableCSRFProtection
 from plonetheme.nuplone.skin.interfaces import NuPloneSkin
@@ -19,15 +22,17 @@ from Products.CMFCore.utils import getToolByName
 from Products.CMFPlone.interfaces import IPloneSiteRoot
 from Products.Five import BrowserView
 from Products.membrane.interfaces.user import IMembraneUser
+from sqlalchemy import and_
+from sqlalchemy import sql
 from time import time
 from zope.component import adapter
 from zope.interface import alsoProvides
 from ZPublisher.BaseRequest import DefaultPublishTraverse
-from sqlalchemy import sql
 
 import logging
 import six
 
+
 log = logging.getLogger(__name__)
 
 
@@ -73,7 +78,7 @@ class EuphorieRefreshResourcesTimestamp(BrowserView):
         )
 
     def __call__(self):
-        """ Refresh the registry record that adds a timestamp
+        """Refresh the registry record that adds a timestamp
         to the resources urls
         """
         self.refresh_timestamp()
@@ -100,7 +105,7 @@ class ManageEnsureInterface(BrowserView):
         return count
 
     def __call__(self):
-        """ Iterate over all risks in the current context and ensure that they have the
+        """Iterate over all risks in the current context and ensure that they have the
         correct interface
         """
         count = self.set_evaluation_method_interfaces()
@@ -133,18 +138,19 @@ class UpdateCompletionPercentage(WebHelpers):
             self.log("Limiting to {} sessions; starting at {}".format(b_size, b_start))
             query = Session.query(SurveySession)
             if "overwrite" not in self.request.form:
-                query = query.filter(SurveySession.completion_percentage == None)
+                query = query.filter(
+                    SurveySession.completion_percentage == None  # noqa: E711
+                )
                 self.log("Ignoring sessions with existing non-null values")
             else:
                 self.log("Overwriting existing non-null values")
             query = (
-                query
-                .join(
+                query.join(
                     Account,
                     sql.and_(
                         Account.id == SurveySession.account_id,
                         Account.account_type != "guest",
-                    )
+                    ),
                 )
                 .order_by(SurveySession.modified.desc())
                 .offset(b_start)
@@ -160,3 +166,81 @@ class UpdateCompletionPercentage(WebHelpers):
                     self.log("Handled {0} out of {1} sessions".format(cnt, total))
             self.log("Done")
         return self.index()
+
+
+class RepairSolutionId(BrowserView):
+    @memoize
+    def get_tool(self, tool_path):
+        return self.client.restrictedTraverse(str(tool_path))
+
+    @memoize
+    def get_risk(self, tool, risk_path):
+        return tool.restrictedTraverse(str(risk_path))
+
+    def __call__(self):
+        site = api.portal.get()
+        self.client = getattr(site, "client")
+        query = (
+            Session.query(ActionPlan, SurveyTreeItem, SurveySession)
+            .filter(
+                sql.and_(
+                    ActionPlan.plan_type == "in_place_standard",
+                    ActionPlan.solution_id == None,  # noqa: E711
+                )
+            )
+            .join(SurveyTreeItem, ActionPlan.risk_id == SurveyTreeItem.id)
+            .join(SurveySession, SurveyTreeItem.session_id == SurveySession.id)
+            .order_by(SurveySession.zodb_path)
+        )
+        count = 0
+        ret = "We have a total of %d measures\n" % query.count()
+
+        for action_plan, risk, session in query.all():
+            tool = self.get_tool(session.zodb_path)
+            risk = self.get_risk(tool, risk.zodb_path)
+            for solution in risk._solutions:
+                if (
+                    solution.action
+                    and action_plan.action
+                    and solution.action.strip() == action_plan.action.strip()
+                ):
+                    action_plan.solution_id = str(solution.id)
+                    count += 1
+                    break
+        ret += "Updated %d measures" % count
+        return ret
+
+
+class FixOmegaPaths(BrowserView):
+    def __call__(self):
+        session = Session()
+
+        custom_risks = session.query(SurveyTreeItem).filter(
+            and_(
+                SurveyTreeItem.zodb_path.notlike("custom-risks%"),
+                SurveyTreeItem.zodb_path.like("%custom-risks%"),
+                SurveyTreeItem.type == "risk",
+            )
+        )
+
+        count = 0
+
+        for risk in custom_risks:
+            i = 1
+            num = risk.zodb_path.split("/")[-1]
+            while i < 100:
+                new_zodb_path = u"custom-risks/{}".format(num)
+                conflict = session.query(SurveyTreeItem).filter(
+                    and_(
+                        SurveyTreeItem.session_id == risk.session_id,
+                        SurveyTreeItem.zodb_path == new_zodb_path,
+                    )
+                )
+                if conflict.count():
+                    num = num = str(int(num) + i)
+                else:
+                    risk.zodb_path = new_zodb_path
+                    count += 1
+                    break
+                i += 1
+        return "Fixed %d omega risks" % count
